<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="开展年度">
            <el-date-picker v-model="querys[2].value" type="year" value-format="yyyy" placeholder="请选择开展年度"
              style="width:100%;" />
          </el-form-item>
          </el-col>
          
          <el-col :span="5">
            <el-form-item label="年度计划任务">
              <el-select clearable filterable style="width:100%" v-model="querys[3].value" placeholder="请选择年度计划任务">
                <el-option v-for="item in cmgtSaftyData" :key="item.id" :label="item.planName"
                  :value="item.id"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="培训项目名称">
              <el-input clearable placeholder="请输入培训项目名称" v-model="querys[0].value" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="活动类别">
              <el-select clearable filterable style="width:100%" v-model="querys[1].value" placeholder="请选择活动类别">
                <el-option v-for="item in trainingTypeSelectOptions" :key="item.value" :label="item.name"
                  :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除</el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>

        <el-table-column fixed width="100" sortable prop="year" label="开展年度" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="planId" label="年度计划任务" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="name" label="培训项目名称" show-overflow-tooltip></el-table-column>
        <el-table-column fixed width="80" prop="subjectType" label="活动类别" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="pxpl" label="培训频次描述" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="content" label="主要培训内容" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="goal" label="培训目标" show-overflow-tooltip></el-table-column>
        <!-- <el-table-column
          fixed
          sortable
          prop="createTime"
          label="创建时间"
          show-overflow-tooltip
        ></el-table-column>

        <el-table-column
          fixed
          sortable
          prop="updateTime"
          label="修改时间"
          show-overflow-tooltip
        ></el-table-column> -->
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <CmgtSaftyTrainingProjectFormDialog ref="formModal"></CmgtSaftyTrainingProjectFormDialog>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'

import CmgtSaftyTrainingProjectApi from '@/views/Manage/saftyTraining/api/CmgtSaftyTrainingProjectApi'
import CmgtSaftyTrainingProjectFormDialog from '@/views/Manage/saftyTraining/components/CmgtSaftyTrainingProjectFormDialog'

export default {
  name: 'CmgtSaftyTrainingProjectManage',
  components: {
    CmgtSaftyTrainingProjectFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      cmgtSaftyData: [],
      url: {
        delete: '/manager/cmgtSaftyTrainingProject/delete'
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'subject_type_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'year_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'plan_id_',
          relation: 'AND',
          value: ''
        },
      ],
      StshowFormDias: false,
      fuelTypes: []
    }
  },
  created() {
    this.cmgtSaftyPlan()
    this.trainingTypeSelectOptions = dictContracts.getDictItemsFromCache('hdlb')
  },
  mounted() { },
  methods: {
    cmgtSaftyPlan() {
      CmgtSaftyTrainingProjectApi.loadcmgtSaftyPlan(
        {
          groupRelation: 'AND',
          groupTree: {},
          pageBean: {
            page: 1,
            pageSize: -1,
            showTotal: true
          },
          sorter: [
            {
              direction: 'DESC',
              property: 'plan_year_'
            }
          ]
        },
        res => {
          console.log(res)
          this.cmgtSaftyData = res.rows
        }
      )
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
      this.querys[3].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      CmgtSaftyTrainingProjectApi.loadCmgtSaftyTrainingProject(
        this.queryParam,
        res => {
          console.log(res, 'res')
          this.total = res.total
          this.tableData = res.rows
          this.tableData.forEach(item => {
            console.log(item)
            this.trainingTypeSelectOptions.forEach(val => {
              if (item.subjectType == val.value) {
                item.subjectType = val.name
              }
            })
            this.cmgtSaftyData.forEach(val => {
              console.log(val)
              if (item.planId == val.id) {
                item.planId = val.planName
              }
            })
          })
          this.$set(this.tableData)
          this.loading = false
        }
      )
    },
    handleDelete() {
      //   console.log(this.multipleSelection)
      CmgtSaftyTrainingProjectApi.deleteCmgtSaftyTrainingProject(
        this.multipleSelection
      )
        .then(res => {
          if (res.state) {
            this.$notify({
              type: 'success',
              message: '删除成功',
              duration: 2000
            })
            this.queryParam.pageBean.page = 1
            this.loadData()
          }
        })
        .catch(res => {
          this.$notify({
            type: 'error',
            message: res.message,
            duration: 2000,
            offset: 80
          })
        })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    // handleClick(item) {
    //   console.log(item.id)
    //   this.StshowFormDias = true
    // },
    closeStshowForm() {
      this.StshowFormDias = false
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
